==> mopd_2.5.3.orig.tar.gz: mopd-2.5.3/common/put.h <==
/*
 * Copyright (c) 1993-95 Mats O Jansson.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by Mats O Jansson.
 * 4. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *	$Id: put.h,v 1.3 1995/10/05 12:26:59 moj Exp $
 *
 */

#ifndef _PUT_H_
#define _PUT_H_

#ifdef NO__P
void	mopPutChar   (/* u_char *, int *, u_char */);
void	mopPutShort  (/* u_char *, int *, u_short */);
void	mopPutLong   (/* u_char *, int *, u_long */);
void	mopPutMulti  (/* u_char *, int *, u_char *, int */);
void	mopPutTime   (/* u_char *, int *, time_t */);
void	mopPutHeader (/* u_char *, int *, u_char *, u_char *, u_short, int */);
void	mopPutLength (/* u_char *, int, u_short */);
#else
__BEGIN_DECLS
void	mopPutChar   __P((u_char *, int *, u_char));
void	mopPutShort  __P((u_char *, int *, u_short));
void	mopPutLong   __P((u_char *, int *, u_long));
void	mopPutMulti  __P((u_char *, int *, u_char *, int));
void	mopPutTime   __P((u_char *, int *, time_t));
void	mopPutHeader __P((u_char *, int *, u_char *, u_char *, u_short, int));
void	mopPutLength __P((u_char *, int, u_short));
__END_DECLS
#endif

#endif _PUT_H_

==> mopd_2.5.4.orig.tar.gz: mopd-2.5.4.orig/common/put.h <==
/*	$NetBSD: put.h,v 1.2 1997/03/25 03:07:34 thorpej Exp $	*/

/*
 * Copyright (c) 1993-95 Mats O Jansson.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by Mats O Jansson.
 * 4. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *	$NetBSD: put.h,v 1.2 1997/03/25 03:07:34 thorpej Exp $
 *
 */

#ifndef _PUT_H_
#define _PUT_H_

__BEGIN_DECLS
void	mopPutChar __P((u_char *, int *, u_char));
void	mopPutShort __P((u_char *, int *, u_short));
void	mopPutLong __P((u_char *, int *, u_int32_t));
void	mopPutMulti __P((u_char *, int *, u_char *, int));
void	mopPutTime __P((u_char *, int *, time_t));
void	mopPutHeader __P((u_char *, int *, u_char *, u_char *, u_short, int));
void	mopPutLength __P((u_char *, int, u_short));
__END_DECLS

#endif /* _PUT_H_ */
